==> pointpos_api-0.2.0.tar.gz: test/employee_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for Employee
void main() {
  var instance = new Employee();

  group('test Employee', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String firstName (default value: null)
    test('to test the property `firstName`', () async {
      // TODO
    });

    // String lastName (default value: null)
    test('to test the property `lastName`', () async {
      // TODO
    });

    // String email (default value: null)
    test('to test the property `email`', () async {
      // TODO
    });

    // String phoneNumber (default value: null)
    test('to test the property `phoneNumber`', () async {
      // TODO
    });

    // String roleId (default value: null)
    test('to test the property `roleId`', () async {
      // TODO
    });

    // String pin (default value: null)
    test('to test the property `pin`', () async {
      // TODO
    });

    // List<String> assignedOutlets (default value: const [])
    test('to test the property `assignedOutlets`', () async {
      // TODO
    });

    // String description (default value: null)
    test('to test the property `description`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: null)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}

==> pointpos_api-0.2.1.tar.gz: test/employee_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for Employee
void main() {
  var instance = new Employee();

  group('test Employee', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String firstName (default value: null)
    test('to test the property `firstName`', () async {
      // TODO
    });

    // String lastName (default value: null)
    test('to test the property `lastName`', () async {
      // TODO
    });

    // String email (default value: null)
    test('to test the property `email`', () async {
      // TODO
    });

    // String phoneNumber (default value: null)
    test('to test the property `phoneNumber`', () async {
      // TODO
    });

    // String roleId (default value: null)
    test('to test the property `roleId`', () async {
      // TODO
    });

    // String pin (default value: null)
    test('to test the property `pin`', () async {
      // TODO
    });

    // String status (default value: null)
    test('to test the property `status`', () async {
      // TODO
    });

    // List<String> assignedOutlets (default value: const [])
    test('to test the property `assignedOutlets`', () async {
      // TODO
    });

    // String description (default value: null)
    test('to test the property `description`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: false)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}
